.. _gallery:


Gallery
========

Here are a few projects using MoviePy. The gallery will fill up as more people start using MoviePy (which is currently one year old). If you have a nice project using MoviePy let us know !

Videos edited with Moviepy
---------------------------


The Cup Song Covers Mix
~~~~~~~~~~~~~~~~~~~~~~~~

This mix of 60 covers of the Cup Song demonstrates the non-linear video editing capabilities of MoviePy. Here is `the (undocumented) MoviePy code <http://nbviewer.ipython.org/github/Zulko/--video-editing---Cup-Song-Covers-Mix/blob/master/CupSongsCovers.ipynb>`_ that generated the script.

.. raw:: html

        <div style="position: relative; padding-bottom: 56.25%; padding-top: 30px; margin-bottom:30px; height: 0; overflow: hidden; 
         margin-left: 5%;">
        <iframe src="http://youtube.com/v/rIehsqqYFEM&hl?rel=0" frameborder="0" allowfullscreen
        style="position: absolute; top: 0; bottom: 10; width: 90%; height: 100%;">
        </iframe>
        </div>

The (old) MoviePy reel video.
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Made when MoviePy was a few weeks old and not as good as now. The code for most scenes can be found
in the :ref:`examples`.

.. raw:: html

       <div style="position: relative; padding-bottom: 56.25%; padding-top: 30px; margin-bottom:30px; height: 0; overflow: hidden; margin-left: 5%;">
       <iframe src="http://youtube.com/v/zGhoZ4UBxEQ&hl?rel=0" frameborder="0" allowfullscreen
       style="position: absolute; top: 0; bottom: 10; left: 0; width: 90%; height: 100%;">
       </iframe>
       </div>


Gifs edited with MoviePy
--------------------------


GIFs from video files
~~~~~~~~~~~~~~~~~~~~~~

This  `tutorial
<http://zulko.github.io/blog/2014/01/23/making-animated-gifs-from-video-files-with-python/>`_ gives you the basics to make gifs from video files (cutting, croping, adding text...). The last example shows how to remove a (still) background to keep only the animated part of a video.


.. raw:: html

         <a href="http://imgur.com/Fo2BxBK"><img src="http://i.imgur.com/Fo2BxBK.gif" title="Hosted by imgur.com"
            style="max-width:50%; height:'auto'; display:block; margin-left: auto;margin-right: auto; margin-bottom:30px;" /></a>

Animations
~~~~~~~~~~~~~

This `tutorial
<http://zulko.github.io/blog/2014/09/20/vector-animations-with-python/>`_ shows how to combine MoviePy with Gizeh to create animations:

.. raw:: html

         <a href="http://imgur.com/2YdW9yf"><img src="http://i.imgur.com/2YdW9yf.gif"
         style="max-width:50%; height:'auto'; display:block; margin-left: auto;margin-right: auto; margin-bottom:30px;" /></a>


It is also possible to combine MoviePy with other graphic librairies like matplotlib, etc.


.. Rinconcam

.. aaa~~~~~~~~~~~

.. Rincomcam (link) is a camera which films surfers on the Californian beach of Point Rincon. At the end of each day it cuts together a video and puts it online. Everything is entirely automatized with Python. MoviePy is used to add transitions, titles and music to the videos.


Scientific or technological projects
-------------------------------------


Piano rolls transcription to sheet music
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This `blog post <http://zulko.github.io/blog/2014/02/12/transcribing-piano-rolls/>`_ explains how to transform a video of a piano roll performance into playable sheet music. MoviePy is used for the frame-by-frame analysis of the piano roll video. The last video is also edited with MoviePy:


.. raw:: html



        <div style="position: relative; padding-bottom: 56.25%; padding-top: 30px; height: 0; margin-bottom:30px; overflow: hidden; margin-left: 5%;">
        <iframe src="http://youtube.com/v/V2XCJNZjm4w&hl?rel=0" frameborder="0" allowfullscreen
        style="position: absolute; top: 0; bottom: 10; left: 0; width: 90%; height: 100%;">
        </iframe>
        </div>



Misc. Programs and Scripts using MoviePy
------------------------------------------

Videogrep
~~~~~~~~~~

Videogrep is a python script written by Sam Lavigne, that goes through the subtitle tracks of movies and makes supercuts based on what it finds. For instance, here is an automatic supercut of every time the White House press secretary tells us what he can tell us:

.. raw:: html

        <div style="position: relative; padding-bottom: 56.25%; padding-top: 30px; margin-bottom:30px; height: 0; overflow: hidden; margin-left: 5%;">
        <iframe src="http://youtube.com/v/D7pymdCU5NQ&hl?rel=0" frameborder="0" allowfullscreen
        style="position: absolute; top: 0; bottom: 10; left: 0; width: 90%; height: 100%;">
        </iframe>
        </div>

Here are Videogrep's introductory `blog post
<http://lav.io/2014/06/videogrep-automatic-supercuts-with-python/>`_ and the Github project `page <https://github.com/antiboredom/videogrep/>`_.

If you liked it, also have a look at these two Videogrep-inspired projects:

- This `blog post <http://zulko.github.io/blog/2014/06/21/some-more-videogreping-with-python/>`_ attempts to cut a video precisely at the beginning and end of sentences or words.
- This `other post <http://zulko.github.io/blog/2014/07/04/automatic-soccer-highlights-compilations-with-python/>`_ uses MoviePy to automatically cut together all the highlights of a soccer game, based on the fact that the crowd cheers louder when something interesting happens.
